# Native Diff Formats Supported by Working Libraries

Based on the test results, here's an analysis of the native diff formats supported by the successfully working libraries:

## 1. diff-match-patch

**Native Format**: Proprietary patch format

**Format Characteristics**:
- Uses a custom binary-like format for patches
- Not compatible with unified diff format
- Represents changes as operations on text segments
- Format example (from the test output):
  ```
  Generated 2 patch(es)
  All patches applied successfully: true
  ```

**Strengths**:
- Optimized for text synchronization
- Handles moved content effectively
- More robust for complex text changes
- Works well with all text file types

## 2. diffparser & parse-diff

**Native Format**: Unified Diff Format (parser only)

**Format Characteristics**:
- Parses standard unified diff format (the format used by `git diff`, `diff -u`, etc.)
- Format example:
  ```diff
  --- file.old
  +++ file.new
  @@ -1,3 +1,4 @@
   unchanged line
  -removed line
  +added line
  +another added line
   unchanged line
  ```

**Strengths**:
- Compatible with standard diff tools
- Human-readable format
- Widely used in version control systems
- These libraries only parse the format, they don't apply patches

## 3. fast-json-patch

**Native Format**: JSON Patch (RFC-6902)

**Format Characteristics**:
- JSON-based format for representing changes to JSON documents
- Uses operations like "add", "remove", "replace", "move", "copy", and "test"
- Format example (from the test output):
  ```json
  [
    {
      "op": "add",
      "path": "/scripts/dev",
      "value": "nodemon index.js"
    },
    {
      "op": "replace",
      "path": "/version",
      "value": "1.1.0"
    }
  ]
  ```

**Strengths**:
- Standardized format (RFC-6902)
- Perfect for JSON data structures
- Supports complex operations like move and copy
- Not suitable for text files or source code

## Comparison of Formats

| Library | Format | Standard | Text Files | JSON | Human-Readable |
|---------|--------|----------|------------|------|----------------|
| diff-match-patch | Proprietary | No | ✅ | ❌ | ❌ |
| diffparser/parse-diff | Unified Diff | Yes | ✅ | ❌ | ✅ |
| fast-json-patch | JSON Patch | Yes (RFC-6902) | ❌ | ✅ | ✅ |

## Conclusion

For working with standard unified diff format patches (like those generated by `git diff` or `diff -u`), the `diffparser` and `parse-diff` libraries are useful for parsing, but they don't apply patches. 

For applying patches to text files, `diff-match-patch` is the most effective library we tested, though it uses its own proprietary format rather than the unified diff format.

For JSON data, `fast-json-patch` provides a standardized approach following RFC-6902.

The command-line `patch` utility (which we used in our initial test data generation) remains the most reliable option for applying standard unified diff format patches to text files.
